==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/DeliveryRuleQueryStringConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.DeliveryRuleQueryStringConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Defines the QueryString condition for the delivery rule.
 * @property name The name of the condition for the delivery rule.
 * Expected value is 'QueryString'.
 * @property parameters Defines the parameters for the condition.
 */
public data class DeliveryRuleQueryStringConditionArgs(
    public val name: Output<String>,
    public val parameters: Output<QueryStringMatchConditionParametersArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.DeliveryRuleQueryStringConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.DeliveryRuleQueryStringConditionArgs =
        com.pulumi.azurenative.cdn.inputs.DeliveryRuleQueryStringConditionArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .parameters(parameters.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [DeliveryRuleQueryStringConditionArgs].
 */
@PulumiTagMarker
public class DeliveryRuleQueryStringConditionArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var parameters: Output<QueryStringMatchConditionParametersArgs>? = null

    /**
     * @param value The name of the condition for the delivery rule.
     * Expected value is 'QueryString'.
     */
    @JvmName("rhhyoacccdwmjfxp")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Defines the parameters for the condition.
     */
    @JvmName("asjxpljnpphqjqdm")
    public suspend fun parameters(`value`: Output<QueryStringMatchConditionParametersArgs>) {
        this.parameters = value
    }

    /**
     * @param value The name of the condition for the delivery rule.
     * Expected value is 'QueryString'.
     */
    @JvmName("rqwwdbwhrwogfocc")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Defines the parameters for the condition.
     */
    @JvmName("olrgafjporexpbgp")
    public suspend fun parameters(`value`: QueryStringMatchConditionParametersArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param argument Defines the parameters for the condition.
     */
    @JvmName("gxfliyhueipnxjxk")
    public suspend
    fun parameters(argument: suspend QueryStringMatchConditionParametersArgsBuilder.() -> Unit) {
        val toBeMapped = QueryStringMatchConditionParametersArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    internal fun build(): DeliveryRuleQueryStringConditionArgs = DeliveryRuleQueryStringConditionArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        parameters = parameters ?: throw PulumiNullFieldException("parameters"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/DeliveryRuleQueryStringConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.DeliveryRuleQueryStringConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Defines the QueryString condition for the delivery rule.
 * @property name The name of the condition for the delivery rule.
 * Expected value is 'QueryString'.
 * @property parameters Defines the parameters for the condition.
 */
public data class DeliveryRuleQueryStringConditionArgs(
    public val name: Output<String>,
    public val parameters: Output<QueryStringMatchConditionParametersArgs>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.DeliveryRuleQueryStringConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.DeliveryRuleQueryStringConditionArgs =
        com.pulumi.azurenative.cdn.inputs.DeliveryRuleQueryStringConditionArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .parameters(parameters.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [DeliveryRuleQueryStringConditionArgs].
 */
@PulumiTagMarker
public class DeliveryRuleQueryStringConditionArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var parameters: Output<QueryStringMatchConditionParametersArgs>? = null

    /**
     * @param value The name of the condition for the delivery rule.
     * Expected value is 'QueryString'.
     */
    @JvmName("kxvflvddcgrymjes")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Defines the parameters for the condition.
     */
    @JvmName("uyunjqxgdrstslpk")
    public suspend fun parameters(`value`: Output<QueryStringMatchConditionParametersArgs>) {
        this.parameters = value
    }

    /**
     * @param value The name of the condition for the delivery rule.
     * Expected value is 'QueryString'.
     */
    @JvmName("dtlbbujfrxcvximr")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Defines the parameters for the condition.
     */
    @JvmName("uderuhmdpehnhiue")
    public suspend fun parameters(`value`: QueryStringMatchConditionParametersArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    /**
     * @param argument Defines the parameters for the condition.
     */
    @JvmName("aftxtrchjdmjatqf")
    public suspend
    fun parameters(argument: suspend QueryStringMatchConditionParametersArgsBuilder.() -> Unit) {
        val toBeMapped = QueryStringMatchConditionParametersArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.parameters = mapped
    }

    internal fun build(): DeliveryRuleQueryStringConditionArgs = DeliveryRuleQueryStringConditionArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        parameters = parameters ?: throw PulumiNullFieldException("parameters"),
    )
}
